import { HttpClientProps } from './http-client-props.js';

declare namespace HttpCache {
    type Driver = 'redis';
    type DriverStorage<DriverType extends Driver> = {
        driver: DriverType;
        config: DriverType extends 'redis' ? {
            port: number;
            host: string;
            keyPrefix?: string;
            keySuffix?: string;
        } : never;
    };
    type Storage<DriverType extends Driver = 'redis'> = HttpCache | DriverStorage<DriverType>;
    type Input = {
        ttl?: number;
        methods?: HttpClientProps.Method[];
        interpretHeader?: boolean;
    };
    type Props = Input & {
        override?: boolean;
    };
}
interface HttpCache {
    set<T = any>(key: string, value: T): void | Promise<void>;
    remove(key: string): void | Promise<void>;
    find<T = any>(key: string): T | Promise<T>;
}

export { HttpCache };
